@@ -4,35 +4,8 @@
 
 (in-package :pgloader.source.sqlite)
 
-(defclass copy-sqlite (db-copy)
-  ((db :accessor db :initarg :db))
-  (:documentation "pgloader SQLite Data Source"))
-
-(defmethod initialize-instance :after ((source copy-sqlite) &key)
-  "Add a default value for transforms in case it's not been provided."
-  (let* ((transforms (when (slot-boundp source 'transforms)
-		       (slot-value source 'transforms))))
-    (when (and (slot-boundp source 'fields) (slot-value source 'fields))
-      ;; cast typically happens in copy-database in the schema structure,
-      ;; and the result is then copied into the copy-mysql instance.
-      (unless (and (slot-boundp source 'columns) (slot-value source 'columns))
-        (setf (slot-value source 'columns)
-              (mapcar #'cast (slot-value source 'fields))))
-
-      (unless transforms
-        (setf (slot-value source 'transforms)
-              (mapcar #'column-transform (slot-value source 'columns)))))))
-
 ;;; Map a function to each row extracted from SQLite
 ;;;
-(defun sqlite-encoding (db)
-  "Return a BABEL suitable encoding for the SQLite db handle."
-  (let ((encoding-string (sqlite:execute-single db "pragma encoding;")))
-    (cond ((string-equal encoding-string "UTF-8")    :utf-8)
-          ((string-equal encoding-string "UTF-16")   :utf-16)
-          ((string-equal encoding-string "UTF-16le") :utf-16le)
-          ((string-equal encoding-string "UTF-16be") :utf-16be))))
-
 (declaim (inline parse-value))
 
 (defun parse-value (value sqlite-type pgsql-type &key (encoding :utf-8))
@@ -111,23 +84,25 @@
                             :use-result-as-rows t
                             :use-result-as-read t
                             :section :pre)
-        (with-connection (conn (source-db sqlite) :check-has-sequences t)
-          (let ((*sqlite-db* (conn-handle conn)))
-            (list-all-columns schema
-                              :db *sqlite-db*
-                              :including including
-                              :excluding excluding
-                              :db-has-sequences (has-sequences conn))
+      (with-connection (conn (source-db sqlite) :check-has-sequences t)
+        (let ((*sqlite-db* (conn-handle conn)))
+          (fetch-columns schema
+                         sqlite
+                         :including including
+                         :excluding excluding
+                         :db-has-sequences (has-sequences conn))
 
-            (when create-indexes
-              (list-all-indexes schema :db *sqlite-db*))
+          (when create-indexes
+            (fetch-indexes schema sqlite))
 
-            (when foreign-keys
-              (list-all-fkeys schema :db *sqlite-db*)))
+          (when foreign-keys
+            (fetch-foreign-keys schema sqlite)))
 
-          ;; return how many objects we're going to deal with in total
-          ;; for stats collection
-          (+ (count-tables catalog) (count-indexes catalog))))
+        ;; return how many objects we're going to deal with in total
+        ;; for stats collection
+        (+ (count-tables catalog)
+           (count-indexes catalog)
+           (count-fkeys catalog))))
     catalog))
 
 
